@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 
 use AnyEvent::RipeRedis;
 use AnyEvent::RipeRedis::Error;
@@ -168,6 +168,8 @@ sub nodes {
 
   my $nodes = $self->_nodes( $slot, $allow_slaves );
 
+  return unless defined $nodes;
+
   return wantarray
       ? @{ $self->{_nodes_pool} }{ @{$nodes} }
       : $self->{_nodes_pool}{ $nodes->[0] };
@@ -654,6 +656,17 @@ sub _route {
   }
 
   my $nodes = $self->_nodes( $slot, $allow_slaves );
+
+  unless ( defined $nodes ) {
+    my $err = _new_error(
+      'ERR Target node not found. Maybe not all slots are served',
+      E_OPRN_ERROR
+    );
+    AE::postpone { $cmd->{on_reply}->( undef, $err ) };
+
+    return;
+  }
+
   $self->_execute( $cmd, $nodes );
 
   return;
@@ -761,6 +774,8 @@ sub _nodes {
     }
     @{ $self->{_slots} };
 
+    return unless defined $range;
+
     return $allow_slaves
         ? $range->[2]
         : [ $range->[2][0] ];
@@ -809,7 +824,7 @@ sub _abort {
   $self->{_temp_queue}  = [];
 
   if ( !defined $err && @queued_commands ) {
-    $err = _new_error( 'Connection closed by client prematurely.',
+    $err = _new_error( 'Connection closed by client prematurely',
         E_CONN_CLOSED_BY_CLIENT );
   }
 
